# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMNaming module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmnaming.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMNaming
else:
    import _XmlMNaming

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMNaming.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMNaming.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMNaming.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMNaming.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMNaming.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMNaming.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMNaming.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMNaming.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMNaming:
_XmlMNaming.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMNaming.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TopTools
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMNaming_NamedShapeDriver_Create() -> "opencascade::handle< XmlMNaming_NamedShapeDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_Create()

def Handle_XmlMNaming_NamedShapeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMNaming_NamedShapeDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_DownCast(t)

def Handle_XmlMNaming_NamedShapeDriver_IsNull(t: "opencascade::handle< XmlMNaming_NamedShapeDriver > const &") -> "bool":
    return _XmlMNaming.Handle_XmlMNaming_NamedShapeDriver_IsNull(t)

def Handle_XmlMNaming_NamingDriver_Create() -> "opencascade::handle< XmlMNaming_NamingDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_Create()

def Handle_XmlMNaming_NamingDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMNaming_NamingDriver >":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_DownCast(t)

def Handle_XmlMNaming_NamingDriver_IsNull(t: "opencascade::handle< XmlMNaming_NamingDriver > const &") -> "bool":
    return _XmlMNaming.Handle_XmlMNaming_NamingDriver_IsNull(t)
class xmlmnaming(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMNaming.xmlmnaming_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMNaming.xmlmnaming_swiginit(self, _XmlMNaming.new_xmlmnaming())
    __swig_destroy__ = _XmlMNaming.delete_xmlmnaming

# Register xmlmnaming in _XmlMNaming:
_XmlMNaming.xmlmnaming_swigregister(xmlmnaming)

def xmlmnaming_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    aMessageDriver: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMNaming.xmlmnaming_AddDrivers(*args)

class XmlMNaming_NamedShapeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_NamedShapeDriver_swiginit(self, _XmlMNaming.new_XmlMNaming_NamedShapeDriver(*args))

    def Clear(self, *args) -> "void":
        r"""
        Clear myshapeset.

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_Clear(self, *args)

    def GetShapesLocations(self, *args) -> "TopTools_LocationSet &":
        r"""
        Get the format of topology.

        Returns
        -------
        TopTools_LocationSet

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_GetShapesLocations(self, *args)

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_Paste(self, *args)

    def ReadShapeSection(self, *args) -> "void":
        r"""
        Input the shapes from dom element.

        Parameters
        ----------
        anElement: XmlObjMgt_Element
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_ReadShapeSection(self, *args)

    def WriteShapeSection(self, *args) -> "void":
        r"""
        Output the shapes into dom element.

        Parameters
        ----------
        anElement: XmlObjMgt_Element
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamedShapeDriver_WriteShapeSection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMNaming_NamedShapeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_NamedShapeDriver

# Register XmlMNaming_NamedShapeDriver in _XmlMNaming:
_XmlMNaming.XmlMNaming_NamedShapeDriver_swigregister(XmlMNaming_NamedShapeDriver)

class XmlMNaming_NamingDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        aMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_NamingDriver_swiginit(self, _XmlMNaming.new_XmlMNaming_NamingDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_NamingDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMNaming_NamingDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_NamingDriver

# Register XmlMNaming_NamingDriver in _XmlMNaming:
_XmlMNaming.XmlMNaming_NamingDriver_swigregister(XmlMNaming_NamingDriver)

class XmlMNaming_Shape1(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Doc: XmlObjMgt_Document

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        E: XmlObjMgt_Element

        Returns
        -------
        None

        """
        _XmlMNaming.XmlMNaming_Shape1_swiginit(self, _XmlMNaming.new_XmlMNaming_Shape1(*args))

    def Element(self, *args) -> "XmlObjMgt_Element const &":
        r"""
        Return myelement.

        Returns
        -------
        XmlObjMgt_Element

        """
        return _XmlMNaming.XmlMNaming_Shape1_Element(self, *args)

    def LocId(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlMNaming.XmlMNaming_Shape1_LocId(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Returns
        -------
        TopAbs_Orientation

        """
        return _XmlMNaming.XmlMNaming_Shape1_Orientation(self, *args)

    def SetShape(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ID: int
        LocID: int
        Orient: TopAbs_Orientation

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_Shape1_SetShape(self, *args)

    def SetVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theVertex: TopoDS_Shape

        Returns
        -------
        None

        """
        return _XmlMNaming.XmlMNaming_Shape1_SetVertex(self, *args)

    def TShapeId(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _XmlMNaming.XmlMNaming_Shape1_TShapeId(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMNaming.delete_XmlMNaming_Shape1

# Register XmlMNaming_Shape1 in _XmlMNaming:
_XmlMNaming.XmlMNaming_Shape1_swigregister(XmlMNaming_Shape1)





