# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMDataStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmdatastd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMDataStd
else:
    import _XmlMDataStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMDataStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMDataStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMDataStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMDataStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMDataStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMDataStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMDataStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMDataStd:
_XmlMDataStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMDataStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMDataStd_AsciiStringDriver_Create() -> "opencascade::handle< XmlMDataStd_AsciiStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_Create()

def Handle_XmlMDataStd_AsciiStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_AsciiStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_DownCast(t)

def Handle_XmlMDataStd_AsciiStringDriver_IsNull(t: "opencascade::handle< XmlMDataStd_AsciiStringDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_AsciiStringDriver_IsNull(t)

def Handle_XmlMDataStd_BooleanArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_BooleanArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_Create()

def Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_BooleanArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t)

def Handle_XmlMDataStd_BooleanArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_BooleanArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanArrayDriver_IsNull(t)

def Handle_XmlMDataStd_BooleanListDriver_Create() -> "opencascade::handle< XmlMDataStd_BooleanListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_Create()

def Handle_XmlMDataStd_BooleanListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_BooleanListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_DownCast(t)

def Handle_XmlMDataStd_BooleanListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_BooleanListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_BooleanListDriver_IsNull(t)

def Handle_XmlMDataStd_ByteArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ByteArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_Create()

def Handle_XmlMDataStd_ByteArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ByteArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ByteArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ByteArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ByteArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ExpressionDriver_Create() -> "opencascade::handle< XmlMDataStd_ExpressionDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_Create()

def Handle_XmlMDataStd_ExpressionDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExpressionDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_DownCast(t)

def Handle_XmlMDataStd_ExpressionDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExpressionDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExpressionDriver_IsNull(t)

def Handle_XmlMDataStd_ExtStringArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ExtStringArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_Create()

def Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExtStringArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ExtStringArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExtStringArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ExtStringListDriver_Create() -> "opencascade::handle< XmlMDataStd_ExtStringListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_Create()

def Handle_XmlMDataStd_ExtStringListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ExtStringListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_DownCast(t)

def Handle_XmlMDataStd_ExtStringListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ExtStringListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ExtStringListDriver_IsNull(t)

def Handle_XmlMDataStd_GenericEmptyDriver_Create() -> "opencascade::handle< XmlMDataStd_GenericEmptyDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_Create()

def Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_GenericEmptyDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t)

def Handle_XmlMDataStd_GenericEmptyDriver_IsNull(t: "opencascade::handle< XmlMDataStd_GenericEmptyDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericEmptyDriver_IsNull(t)

def Handle_XmlMDataStd_GenericExtStringDriver_Create() -> "opencascade::handle< XmlMDataStd_GenericExtStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_Create()

def Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_GenericExtStringDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t)

def Handle_XmlMDataStd_GenericExtStringDriver_IsNull(t: "opencascade::handle< XmlMDataStd_GenericExtStringDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_GenericExtStringDriver_IsNull(t)

def Handle_XmlMDataStd_IntPackedMapDriver_Create() -> "opencascade::handle< XmlMDataStd_IntPackedMapDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_Create()

def Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntPackedMapDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t)

def Handle_XmlMDataStd_IntPackedMapDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntPackedMapDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntPackedMapDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_Create()

def Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerArrayDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_Create()

def Handle_XmlMDataStd_IntegerDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerDriver_IsNull(t)

def Handle_XmlMDataStd_IntegerListDriver_Create() -> "opencascade::handle< XmlMDataStd_IntegerListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_Create()

def Handle_XmlMDataStd_IntegerListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_IntegerListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_DownCast(t)

def Handle_XmlMDataStd_IntegerListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_IntegerListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_IntegerListDriver_IsNull(t)

def Handle_XmlMDataStd_NamedDataDriver_Create() -> "opencascade::handle< XmlMDataStd_NamedDataDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_Create()

def Handle_XmlMDataStd_NamedDataDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_NamedDataDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_DownCast(t)

def Handle_XmlMDataStd_NamedDataDriver_IsNull(t: "opencascade::handle< XmlMDataStd_NamedDataDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_NamedDataDriver_IsNull(t)

def Handle_XmlMDataStd_RealArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_RealArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_Create()

def Handle_XmlMDataStd_RealArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_DownCast(t)

def Handle_XmlMDataStd_RealArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealArrayDriver_IsNull(t)

def Handle_XmlMDataStd_RealDriver_Create() -> "opencascade::handle< XmlMDataStd_RealDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_Create()

def Handle_XmlMDataStd_RealDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_DownCast(t)

def Handle_XmlMDataStd_RealDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealDriver_IsNull(t)

def Handle_XmlMDataStd_RealListDriver_Create() -> "opencascade::handle< XmlMDataStd_RealListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_Create()

def Handle_XmlMDataStd_RealListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_RealListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_DownCast(t)

def Handle_XmlMDataStd_RealListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_RealListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_RealListDriver_IsNull(t)

def Handle_XmlMDataStd_ReferenceArrayDriver_Create() -> "opencascade::handle< XmlMDataStd_ReferenceArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_Create()

def Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ReferenceArrayDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t)

def Handle_XmlMDataStd_ReferenceArrayDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ReferenceArrayDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceArrayDriver_IsNull(t)

def Handle_XmlMDataStd_ReferenceListDriver_Create() -> "opencascade::handle< XmlMDataStd_ReferenceListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_Create()

def Handle_XmlMDataStd_ReferenceListDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_ReferenceListDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_DownCast(t)

def Handle_XmlMDataStd_ReferenceListDriver_IsNull(t: "opencascade::handle< XmlMDataStd_ReferenceListDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_ReferenceListDriver_IsNull(t)

def Handle_XmlMDataStd_TreeNodeDriver_Create() -> "opencascade::handle< XmlMDataStd_TreeNodeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_Create()

def Handle_XmlMDataStd_TreeNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_TreeNodeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_DownCast(t)

def Handle_XmlMDataStd_TreeNodeDriver_IsNull(t: "opencascade::handle< XmlMDataStd_TreeNodeDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_TreeNodeDriver_IsNull(t)

def Handle_XmlMDataStd_UAttributeDriver_Create() -> "opencascade::handle< XmlMDataStd_UAttributeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_Create()

def Handle_XmlMDataStd_UAttributeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_UAttributeDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_DownCast(t)

def Handle_XmlMDataStd_UAttributeDriver_IsNull(t: "opencascade::handle< XmlMDataStd_UAttributeDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_UAttributeDriver_IsNull(t)

def Handle_XmlMDataStd_VariableDriver_Create() -> "opencascade::handle< XmlMDataStd_VariableDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_Create()

def Handle_XmlMDataStd_VariableDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMDataStd_VariableDriver >":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_DownCast(t)

def Handle_XmlMDataStd_VariableDriver_IsNull(t: "opencascade::handle< XmlMDataStd_VariableDriver > const &") -> "bool":
    return _XmlMDataStd.Handle_XmlMDataStd_VariableDriver_IsNull(t)
class xmlmdatastd(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        anMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMDataStd.xmlmdatastd_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMDataStd.xmlmdatastd_swiginit(self, _XmlMDataStd.new_xmlmdatastd())
    __swig_destroy__ = _XmlMDataStd.delete_xmlmdatastd

# Register xmlmdatastd in _XmlMDataStd:
_XmlMDataStd.xmlmdatastd_swigregister(xmlmdatastd)

def xmlmdatastd_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    anMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMDataStd.xmlmdatastd_AddDrivers(*args)

class XmlMDataStd_AsciiStringDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_AsciiStringDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_AsciiStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_AsciiStringDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_AsciiStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_AsciiStringDriver

# Register XmlMDataStd_AsciiStringDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_AsciiStringDriver_swigregister(XmlMDataStd_AsciiStringDriver)

class XmlMDataStd_BooleanArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_BooleanArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_BooleanArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_BooleanArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_BooleanArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_BooleanArrayDriver

# Register XmlMDataStd_BooleanArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_BooleanArrayDriver_swigregister(XmlMDataStd_BooleanArrayDriver)

class XmlMDataStd_BooleanListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_BooleanListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_BooleanListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_BooleanListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_BooleanListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_BooleanListDriver

# Register XmlMDataStd_BooleanListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_BooleanListDriver_swigregister(XmlMDataStd_BooleanListDriver)

class XmlMDataStd_ByteArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ByteArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ByteArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ByteArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ByteArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ByteArrayDriver

# Register XmlMDataStd_ByteArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ByteArrayDriver_swigregister(XmlMDataStd_ByteArrayDriver)

class XmlMDataStd_ExpressionDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExpressionDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExpressionDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExpressionDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExpressionDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExpressionDriver

# Register XmlMDataStd_ExpressionDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExpressionDriver_swigregister(XmlMDataStd_ExpressionDriver)

class XmlMDataStd_ExtStringArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExtStringArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExtStringArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExtStringArrayDriver

# Register XmlMDataStd_ExtStringArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExtStringArrayDriver_swigregister(XmlMDataStd_ExtStringArrayDriver)

class XmlMDataStd_ExtStringListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ExtStringListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ExtStringListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ExtStringListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ExtStringListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ExtStringListDriver

# Register XmlMDataStd_ExtStringListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ExtStringListDriver_swigregister(XmlMDataStd_ExtStringListDriver)

class XmlMDataStd_GenericEmptyDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_GenericEmptyDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_GenericEmptyDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_GenericEmptyDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_GenericEmptyDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_GenericEmptyDriver

# Register XmlMDataStd_GenericEmptyDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_GenericEmptyDriver_swigregister(XmlMDataStd_GenericEmptyDriver)

class XmlMDataStd_GenericExtStringDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_GenericExtStringDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_GenericExtStringDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_GenericExtStringDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_GenericExtStringDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_GenericExtStringDriver

# Register XmlMDataStd_GenericExtStringDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_GenericExtStringDriver_swigregister(XmlMDataStd_GenericExtStringDriver)

class XmlMDataStd_IntPackedMapDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntPackedMapDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntPackedMapDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Persistent -> transient (retrieve).

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Transient -> persistent (store).

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntPackedMapDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntPackedMapDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntPackedMapDriver

# Register XmlMDataStd_IntPackedMapDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntPackedMapDriver_swigregister(XmlMDataStd_IntPackedMapDriver)

class XmlMDataStd_IntegerArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerArrayDriver

# Register XmlMDataStd_IntegerArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerArrayDriver_swigregister(XmlMDataStd_IntegerArrayDriver)

class XmlMDataStd_IntegerDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerDriver

# Register XmlMDataStd_IntegerDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerDriver_swigregister(XmlMDataStd_IntegerDriver)

class XmlMDataStd_IntegerListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_IntegerListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_IntegerListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_IntegerListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_IntegerListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_IntegerListDriver

# Register XmlMDataStd_IntegerListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_IntegerListDriver_swigregister(XmlMDataStd_IntegerListDriver)

class XmlMDataStd_NamedDataDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_NamedDataDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_NamedDataDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_NamedDataDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_NamedDataDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_NamedDataDriver

# Register XmlMDataStd_NamedDataDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_NamedDataDriver_swigregister(XmlMDataStd_NamedDataDriver)

class XmlMDataStd_RealArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealArrayDriver

# Register XmlMDataStd_RealArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealArrayDriver_swigregister(XmlMDataStd_RealArrayDriver)

class XmlMDataStd_RealDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealDriver

# Register XmlMDataStd_RealDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealDriver_swigregister(XmlMDataStd_RealDriver)

class XmlMDataStd_RealListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_RealListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_RealListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_RealListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_RealListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_RealListDriver

# Register XmlMDataStd_RealListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_RealListDriver_swigregister(XmlMDataStd_RealListDriver)

class XmlMDataStd_ReferenceArrayDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ReferenceArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ReferenceArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ReferenceArrayDriver

# Register XmlMDataStd_ReferenceArrayDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ReferenceArrayDriver_swigregister(XmlMDataStd_ReferenceArrayDriver)

class XmlMDataStd_ReferenceListDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_ReferenceListDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_ReferenceListDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_ReferenceListDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_ReferenceListDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_ReferenceListDriver

# Register XmlMDataStd_ReferenceListDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_ReferenceListDriver_swigregister(XmlMDataStd_ReferenceListDriver)

class XmlMDataStd_TreeNodeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_TreeNodeDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_TreeNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_TreeNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_TreeNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_TreeNodeDriver

# Register XmlMDataStd_TreeNodeDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_TreeNodeDriver_swigregister(XmlMDataStd_TreeNodeDriver)

class XmlMDataStd_UAttributeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_UAttributeDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_UAttributeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_UAttributeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_UAttributeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_UAttributeDriver

# Register XmlMDataStd_UAttributeDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_UAttributeDriver_swigregister(XmlMDataStd_UAttributeDriver)

class XmlMDataStd_VariableDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMDataStd.XmlMDataStd_VariableDriver_swiginit(self, _XmlMDataStd.new_XmlMDataStd_VariableDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMDataStd.XmlMDataStd_VariableDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMDataStd_VariableDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMDataStd.delete_XmlMDataStd_VariableDriver

# Register XmlMDataStd_VariableDriver in _XmlMDataStd:
_XmlMDataStd.XmlMDataStd_VariableDriver_swigregister(XmlMDataStd_VariableDriver)





