# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepToGeom module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_steptogeom.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepToGeom
else:
    import _StepToGeom

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepToGeom.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepToGeom.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepToGeom.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepToGeom.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepToGeom.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepToGeom.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepToGeom.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepToGeom.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepToGeom.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepToGeom.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepToGeom.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepToGeom.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepToGeom.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepToGeom.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepToGeom.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepToGeom.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepToGeom.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepToGeom:
_StepToGeom.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepToGeom.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepGeom
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *



class steptogeom(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def MakeAxis1Placement(*args) -> "opencascade::handle< Geom_Axis1Placement >":
        r"""
        No available documentation.

        Parameters
        ----------
        SA: StepGeom_Axis1Placement

        Returns
        -------
        opencascade::handle<Geom_Axis1Placement>

        """
        return _StepToGeom.steptogeom_MakeAxis1Placement(*args)

    @staticmethod
    def MakeAxis2Placement(*args) -> "opencascade::handle< Geom_Axis2Placement >":
        r"""
        No available documentation.

        Parameters
        ----------
        SA: StepGeom_Axis2Placement3d

        Returns
        -------
        opencascade::handle<Geom_Axis2Placement>

        """
        return _StepToGeom.steptogeom_MakeAxis2Placement(*args)

    @staticmethod
    def MakeAxisPlacement(*args) -> "opencascade::handle< Geom2d_AxisPlacement >":
        r"""
        No available documentation.

        Parameters
        ----------
        SA: StepGeom_Axis2Placement2d

        Returns
        -------
        opencascade::handle<Geom2d_AxisPlacement>

        """
        return _StepToGeom.steptogeom_MakeAxisPlacement(*args)

    @staticmethod
    def MakeBSplineCurve(*args) -> "opencascade::handle< Geom_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_BSplineCurve

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>

        """
        return _StepToGeom.steptogeom_MakeBSplineCurve(*args)

    @staticmethod
    def MakeBSplineCurve2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_BSplineCurve

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _StepToGeom.steptogeom_MakeBSplineCurve2d(*args)

    @staticmethod
    def MakeBSplineSurface(*args) -> "opencascade::handle< Geom_BSplineSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_BSplineSurface

        Returns
        -------
        opencascade::handle<Geom_BSplineSurface>

        """
        return _StepToGeom.steptogeom_MakeBSplineSurface(*args)

    @staticmethod
    def MakeBoundedCurve(*args) -> "opencascade::handle< Geom_BoundedCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_BoundedCurve

        Returns
        -------
        opencascade::handle<Geom_BoundedCurve>

        """
        return _StepToGeom.steptogeom_MakeBoundedCurve(*args)

    @staticmethod
    def MakeBoundedCurve2d(*args) -> "opencascade::handle< Geom2d_BoundedCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_BoundedCurve

        Returns
        -------
        opencascade::handle<Geom2d_BoundedCurve>

        """
        return _StepToGeom.steptogeom_MakeBoundedCurve2d(*args)

    @staticmethod
    def MakeBoundedSurface(*args) -> "opencascade::handle< Geom_BoundedSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_BoundedSurface

        Returns
        -------
        opencascade::handle<Geom_BoundedSurface>

        """
        return _StepToGeom.steptogeom_MakeBoundedSurface(*args)

    @staticmethod
    def MakeCartesianPoint(*args) -> "opencascade::handle< Geom_CartesianPoint >":
        r"""
        No available documentation.

        Parameters
        ----------
        SP: StepGeom_CartesianPoint

        Returns
        -------
        opencascade::handle<Geom_CartesianPoint>

        """
        return _StepToGeom.steptogeom_MakeCartesianPoint(*args)

    @staticmethod
    def MakeCartesianPoint2d(*args) -> "opencascade::handle< Geom2d_CartesianPoint >":
        r"""
        No available documentation.

        Parameters
        ----------
        SP: StepGeom_CartesianPoint

        Returns
        -------
        opencascade::handle<Geom2d_CartesianPoint>

        """
        return _StepToGeom.steptogeom_MakeCartesianPoint2d(*args)

    @staticmethod
    def MakeCircle(*args) -> "opencascade::handle< Geom_Circle >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Circle

        Returns
        -------
        opencascade::handle<Geom_Circle>

        """
        return _StepToGeom.steptogeom_MakeCircle(*args)

    @staticmethod
    def MakeCircle2d(*args) -> "opencascade::handle< Geom2d_Circle >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Circle

        Returns
        -------
        opencascade::handle<Geom2d_Circle>

        """
        return _StepToGeom.steptogeom_MakeCircle2d(*args)

    @staticmethod
    def MakeConic(*args) -> "opencascade::handle< Geom_Conic >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Conic

        Returns
        -------
        opencascade::handle<Geom_Conic>

        """
        return _StepToGeom.steptogeom_MakeConic(*args)

    @staticmethod
    def MakeConic2d(*args) -> "opencascade::handle< Geom2d_Conic >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Conic

        Returns
        -------
        opencascade::handle<Geom2d_Conic>

        """
        return _StepToGeom.steptogeom_MakeConic2d(*args)

    @staticmethod
    def MakeConicalSurface(*args) -> "opencascade::handle< Geom_ConicalSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_ConicalSurface

        Returns
        -------
        opencascade::handle<Geom_ConicalSurface>

        """
        return _StepToGeom.steptogeom_MakeConicalSurface(*args)

    @staticmethod
    def MakeCurve(*args) -> "opencascade::handle< Geom_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Curve

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _StepToGeom.steptogeom_MakeCurve(*args)

    @staticmethod
    def MakeCurve2d(*args) -> "opencascade::handle< Geom2d_Curve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Curve

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _StepToGeom.steptogeom_MakeCurve2d(*args)

    @staticmethod
    def MakeCylindricalSurface(*args) -> "opencascade::handle< Geom_CylindricalSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_CylindricalSurface

        Returns
        -------
        opencascade::handle<Geom_CylindricalSurface>

        """
        return _StepToGeom.steptogeom_MakeCylindricalSurface(*args)

    @staticmethod
    def MakeDirection(*args) -> "opencascade::handle< Geom_Direction >":
        r"""
        No available documentation.

        Parameters
        ----------
        SD: StepGeom_Direction

        Returns
        -------
        opencascade::handle<Geom_Direction>

        """
        return _StepToGeom.steptogeom_MakeDirection(*args)

    @staticmethod
    def MakeDirection2d(*args) -> "opencascade::handle< Geom2d_Direction >":
        r"""
        No available documentation.

        Parameters
        ----------
        SD: StepGeom_Direction

        Returns
        -------
        opencascade::handle<Geom2d_Direction>

        """
        return _StepToGeom.steptogeom_MakeDirection2d(*args)

    @staticmethod
    def MakeElementarySurface(*args) -> "opencascade::handle< Geom_ElementarySurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_ElementarySurface

        Returns
        -------
        opencascade::handle<Geom_ElementarySurface>

        """
        return _StepToGeom.steptogeom_MakeElementarySurface(*args)

    @staticmethod
    def MakeEllipse(*args) -> "opencascade::handle< Geom_Ellipse >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Ellipse

        Returns
        -------
        opencascade::handle<Geom_Ellipse>

        """
        return _StepToGeom.steptogeom_MakeEllipse(*args)

    @staticmethod
    def MakeEllipse2d(*args) -> "opencascade::handle< Geom2d_Ellipse >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Ellipse

        Returns
        -------
        opencascade::handle<Geom2d_Ellipse>

        """
        return _StepToGeom.steptogeom_MakeEllipse2d(*args)

    @staticmethod
    def MakeHyperbola(*args) -> "opencascade::handle< Geom_Hyperbola >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Hyperbola

        Returns
        -------
        opencascade::handle<Geom_Hyperbola>

        """
        return _StepToGeom.steptogeom_MakeHyperbola(*args)

    @staticmethod
    def MakeHyperbola2d(*args) -> "opencascade::handle< Geom2d_Hyperbola >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Hyperbola

        Returns
        -------
        opencascade::handle<Geom2d_Hyperbola>

        """
        return _StepToGeom.steptogeom_MakeHyperbola2d(*args)

    @staticmethod
    def MakeLine(*args) -> "opencascade::handle< Geom_Line >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Line

        Returns
        -------
        opencascade::handle<Geom_Line>

        """
        return _StepToGeom.steptogeom_MakeLine(*args)

    @staticmethod
    def MakeLine2d(*args) -> "opencascade::handle< Geom2d_Line >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Line

        Returns
        -------
        opencascade::handle<Geom2d_Line>

        """
        return _StepToGeom.steptogeom_MakeLine2d(*args)

    @staticmethod
    def MakeParabola(*args) -> "opencascade::handle< Geom_Parabola >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Parabola

        Returns
        -------
        opencascade::handle<Geom_Parabola>

        """
        return _StepToGeom.steptogeom_MakeParabola(*args)

    @staticmethod
    def MakeParabola2d(*args) -> "opencascade::handle< Geom2d_Parabola >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_Parabola

        Returns
        -------
        opencascade::handle<Geom2d_Parabola>

        """
        return _StepToGeom.steptogeom_MakeParabola2d(*args)

    @staticmethod
    def MakePlane(*args) -> "opencascade::handle< Geom_Plane >":
        r"""
        No available documentation.

        Parameters
        ----------
        SP: StepGeom_Plane

        Returns
        -------
        opencascade::handle<Geom_Plane>

        """
        return _StepToGeom.steptogeom_MakePlane(*args)

    @staticmethod
    def MakePolyline(*args) -> "opencascade::handle< Geom_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SPL: StepGeom_Polyline

        Returns
        -------
        opencascade::handle<Geom_BSplineCurve>

        """
        return _StepToGeom.steptogeom_MakePolyline(*args)

    @staticmethod
    def MakePolyline2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SPL: StepGeom_Polyline

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _StepToGeom.steptogeom_MakePolyline2d(*args)

    @staticmethod
    def MakeRectangularTrimmedSurface(*args) -> "opencascade::handle< Geom_RectangularTrimmedSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_RectangularTrimmedSurface

        Returns
        -------
        opencascade::handle<Geom_RectangularTrimmedSurface>

        """
        return _StepToGeom.steptogeom_MakeRectangularTrimmedSurface(*args)

    @staticmethod
    def MakeSphericalSurface(*args) -> "opencascade::handle< Geom_SphericalSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_SphericalSurface

        Returns
        -------
        opencascade::handle<Geom_SphericalSurface>

        """
        return _StepToGeom.steptogeom_MakeSphericalSurface(*args)

    @staticmethod
    def MakeSurface(*args) -> "opencascade::handle< Geom_Surface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_Surface

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _StepToGeom.steptogeom_MakeSurface(*args)

    @staticmethod
    def MakeSurfaceOfLinearExtrusion(*args) -> "opencascade::handle< Geom_SurfaceOfLinearExtrusion >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_SurfaceOfLinearExtrusion

        Returns
        -------
        opencascade::handle<Geom_SurfaceOfLinearExtrusion>

        """
        return _StepToGeom.steptogeom_MakeSurfaceOfLinearExtrusion(*args)

    @staticmethod
    def MakeSurfaceOfRevolution(*args) -> "opencascade::handle< Geom_SurfaceOfRevolution >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_SurfaceOfRevolution

        Returns
        -------
        opencascade::handle<Geom_SurfaceOfRevolution>

        """
        return _StepToGeom.steptogeom_MakeSurfaceOfRevolution(*args)

    @staticmethod
    def MakeSweptSurface(*args) -> "opencascade::handle< Geom_SweptSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_SweptSurface

        Returns
        -------
        opencascade::handle<Geom_SweptSurface>

        """
        return _StepToGeom.steptogeom_MakeSweptSurface(*args)

    @staticmethod
    def MakeToroidalSurface(*args) -> "opencascade::handle< Geom_ToroidalSurface >":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: StepGeom_ToroidalSurface

        Returns
        -------
        opencascade::handle<Geom_ToroidalSurface>

        """
        return _StepToGeom.steptogeom_MakeToroidalSurface(*args)

    @staticmethod
    def MakeTransformation2d(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        SCTO: StepGeom_CartesianTransformationOperator2d
        CT: gp_Trsf2d

        Returns
        -------
        bool

        """
        return _StepToGeom.steptogeom_MakeTransformation2d(*args)

    @staticmethod
    def MakeTransformation3d(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        SCTO: StepGeom_CartesianTransformationOperator3d
        CT: gp_Trsf

        Returns
        -------
        bool

        """
        return _StepToGeom.steptogeom_MakeTransformation3d(*args)

    @staticmethod
    def MakeTrimmedCurve(*args) -> "opencascade::handle< Geom_TrimmedCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_TrimmedCurve

        Returns
        -------
        opencascade::handle<Geom_TrimmedCurve>

        """
        return _StepToGeom.steptogeom_MakeTrimmedCurve(*args)

    @staticmethod
    def MakeTrimmedCurve2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
        r"""
        No available documentation.

        Parameters
        ----------
        SC: StepGeom_TrimmedCurve

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _StepToGeom.steptogeom_MakeTrimmedCurve2d(*args)

    @staticmethod
    def MakeVectorWithMagnitude(*args) -> "opencascade::handle< Geom_VectorWithMagnitude >":
        r"""
        No available documentation.

        Parameters
        ----------
        SV: StepGeom_Vector

        Returns
        -------
        opencascade::handle<Geom_VectorWithMagnitude>

        """
        return _StepToGeom.steptogeom_MakeVectorWithMagnitude(*args)

    @staticmethod
    def MakeVectorWithMagnitude2d(*args) -> "opencascade::handle< Geom2d_VectorWithMagnitude >":
        r"""
        No available documentation.

        Parameters
        ----------
        SV: StepGeom_Vector

        Returns
        -------
        opencascade::handle<Geom2d_VectorWithMagnitude>

        """
        return _StepToGeom.steptogeom_MakeVectorWithMagnitude2d(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _StepToGeom.steptogeom_swiginit(self, _StepToGeom.new_steptogeom())
    __swig_destroy__ = _StepToGeom.delete_steptogeom

# Register steptogeom in _StepToGeom:
_StepToGeom.steptogeom_swigregister(steptogeom)

def steptogeom_MakeAxis1Placement(*args) -> "opencascade::handle< Geom_Axis1Placement >":
    r"""
    No available documentation.

    Parameters
    ----------
    SA: StepGeom_Axis1Placement

    Returns
    -------
    opencascade::handle<Geom_Axis1Placement>

    """
    return _StepToGeom.steptogeom_MakeAxis1Placement(*args)

def steptogeom_MakeAxis2Placement(*args) -> "opencascade::handle< Geom_Axis2Placement >":
    r"""
    No available documentation.

    Parameters
    ----------
    SA: StepGeom_Axis2Placement3d

    Returns
    -------
    opencascade::handle<Geom_Axis2Placement>

    """
    return _StepToGeom.steptogeom_MakeAxis2Placement(*args)

def steptogeom_MakeAxisPlacement(*args) -> "opencascade::handle< Geom2d_AxisPlacement >":
    r"""
    No available documentation.

    Parameters
    ----------
    SA: StepGeom_Axis2Placement2d

    Returns
    -------
    opencascade::handle<Geom2d_AxisPlacement>

    """
    return _StepToGeom.steptogeom_MakeAxisPlacement(*args)

def steptogeom_MakeBSplineCurve(*args) -> "opencascade::handle< Geom_BSplineCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_BSplineCurve

    Returns
    -------
    opencascade::handle<Geom_BSplineCurve>

    """
    return _StepToGeom.steptogeom_MakeBSplineCurve(*args)

def steptogeom_MakeBSplineCurve2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_BSplineCurve

    Returns
    -------
    opencascade::handle<Geom2d_BSplineCurve>

    """
    return _StepToGeom.steptogeom_MakeBSplineCurve2d(*args)

def steptogeom_MakeBSplineSurface(*args) -> "opencascade::handle< Geom_BSplineSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_BSplineSurface

    Returns
    -------
    opencascade::handle<Geom_BSplineSurface>

    """
    return _StepToGeom.steptogeom_MakeBSplineSurface(*args)

def steptogeom_MakeBoundedCurve(*args) -> "opencascade::handle< Geom_BoundedCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_BoundedCurve

    Returns
    -------
    opencascade::handle<Geom_BoundedCurve>

    """
    return _StepToGeom.steptogeom_MakeBoundedCurve(*args)

def steptogeom_MakeBoundedCurve2d(*args) -> "opencascade::handle< Geom2d_BoundedCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_BoundedCurve

    Returns
    -------
    opencascade::handle<Geom2d_BoundedCurve>

    """
    return _StepToGeom.steptogeom_MakeBoundedCurve2d(*args)

def steptogeom_MakeBoundedSurface(*args) -> "opencascade::handle< Geom_BoundedSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_BoundedSurface

    Returns
    -------
    opencascade::handle<Geom_BoundedSurface>

    """
    return _StepToGeom.steptogeom_MakeBoundedSurface(*args)

def steptogeom_MakeCartesianPoint(*args) -> "opencascade::handle< Geom_CartesianPoint >":
    r"""
    No available documentation.

    Parameters
    ----------
    SP: StepGeom_CartesianPoint

    Returns
    -------
    opencascade::handle<Geom_CartesianPoint>

    """
    return _StepToGeom.steptogeom_MakeCartesianPoint(*args)

def steptogeom_MakeCartesianPoint2d(*args) -> "opencascade::handle< Geom2d_CartesianPoint >":
    r"""
    No available documentation.

    Parameters
    ----------
    SP: StepGeom_CartesianPoint

    Returns
    -------
    opencascade::handle<Geom2d_CartesianPoint>

    """
    return _StepToGeom.steptogeom_MakeCartesianPoint2d(*args)

def steptogeom_MakeCircle(*args) -> "opencascade::handle< Geom_Circle >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Circle

    Returns
    -------
    opencascade::handle<Geom_Circle>

    """
    return _StepToGeom.steptogeom_MakeCircle(*args)

def steptogeom_MakeCircle2d(*args) -> "opencascade::handle< Geom2d_Circle >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Circle

    Returns
    -------
    opencascade::handle<Geom2d_Circle>

    """
    return _StepToGeom.steptogeom_MakeCircle2d(*args)

def steptogeom_MakeConic(*args) -> "opencascade::handle< Geom_Conic >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Conic

    Returns
    -------
    opencascade::handle<Geom_Conic>

    """
    return _StepToGeom.steptogeom_MakeConic(*args)

def steptogeom_MakeConic2d(*args) -> "opencascade::handle< Geom2d_Conic >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Conic

    Returns
    -------
    opencascade::handle<Geom2d_Conic>

    """
    return _StepToGeom.steptogeom_MakeConic2d(*args)

def steptogeom_MakeConicalSurface(*args) -> "opencascade::handle< Geom_ConicalSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_ConicalSurface

    Returns
    -------
    opencascade::handle<Geom_ConicalSurface>

    """
    return _StepToGeom.steptogeom_MakeConicalSurface(*args)

def steptogeom_MakeCurve(*args) -> "opencascade::handle< Geom_Curve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Curve

    Returns
    -------
    opencascade::handle<Geom_Curve>

    """
    return _StepToGeom.steptogeom_MakeCurve(*args)

def steptogeom_MakeCurve2d(*args) -> "opencascade::handle< Geom2d_Curve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Curve

    Returns
    -------
    opencascade::handle<Geom2d_Curve>

    """
    return _StepToGeom.steptogeom_MakeCurve2d(*args)

def steptogeom_MakeCylindricalSurface(*args) -> "opencascade::handle< Geom_CylindricalSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_CylindricalSurface

    Returns
    -------
    opencascade::handle<Geom_CylindricalSurface>

    """
    return _StepToGeom.steptogeom_MakeCylindricalSurface(*args)

def steptogeom_MakeDirection(*args) -> "opencascade::handle< Geom_Direction >":
    r"""
    No available documentation.

    Parameters
    ----------
    SD: StepGeom_Direction

    Returns
    -------
    opencascade::handle<Geom_Direction>

    """
    return _StepToGeom.steptogeom_MakeDirection(*args)

def steptogeom_MakeDirection2d(*args) -> "opencascade::handle< Geom2d_Direction >":
    r"""
    No available documentation.

    Parameters
    ----------
    SD: StepGeom_Direction

    Returns
    -------
    opencascade::handle<Geom2d_Direction>

    """
    return _StepToGeom.steptogeom_MakeDirection2d(*args)

def steptogeom_MakeElementarySurface(*args) -> "opencascade::handle< Geom_ElementarySurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_ElementarySurface

    Returns
    -------
    opencascade::handle<Geom_ElementarySurface>

    """
    return _StepToGeom.steptogeom_MakeElementarySurface(*args)

def steptogeom_MakeEllipse(*args) -> "opencascade::handle< Geom_Ellipse >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Ellipse

    Returns
    -------
    opencascade::handle<Geom_Ellipse>

    """
    return _StepToGeom.steptogeom_MakeEllipse(*args)

def steptogeom_MakeEllipse2d(*args) -> "opencascade::handle< Geom2d_Ellipse >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Ellipse

    Returns
    -------
    opencascade::handle<Geom2d_Ellipse>

    """
    return _StepToGeom.steptogeom_MakeEllipse2d(*args)

def steptogeom_MakeHyperbola(*args) -> "opencascade::handle< Geom_Hyperbola >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Hyperbola

    Returns
    -------
    opencascade::handle<Geom_Hyperbola>

    """
    return _StepToGeom.steptogeom_MakeHyperbola(*args)

def steptogeom_MakeHyperbola2d(*args) -> "opencascade::handle< Geom2d_Hyperbola >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Hyperbola

    Returns
    -------
    opencascade::handle<Geom2d_Hyperbola>

    """
    return _StepToGeom.steptogeom_MakeHyperbola2d(*args)

def steptogeom_MakeLine(*args) -> "opencascade::handle< Geom_Line >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Line

    Returns
    -------
    opencascade::handle<Geom_Line>

    """
    return _StepToGeom.steptogeom_MakeLine(*args)

def steptogeom_MakeLine2d(*args) -> "opencascade::handle< Geom2d_Line >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Line

    Returns
    -------
    opencascade::handle<Geom2d_Line>

    """
    return _StepToGeom.steptogeom_MakeLine2d(*args)

def steptogeom_MakeParabola(*args) -> "opencascade::handle< Geom_Parabola >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Parabola

    Returns
    -------
    opencascade::handle<Geom_Parabola>

    """
    return _StepToGeom.steptogeom_MakeParabola(*args)

def steptogeom_MakeParabola2d(*args) -> "opencascade::handle< Geom2d_Parabola >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_Parabola

    Returns
    -------
    opencascade::handle<Geom2d_Parabola>

    """
    return _StepToGeom.steptogeom_MakeParabola2d(*args)

def steptogeom_MakePlane(*args) -> "opencascade::handle< Geom_Plane >":
    r"""
    No available documentation.

    Parameters
    ----------
    SP: StepGeom_Plane

    Returns
    -------
    opencascade::handle<Geom_Plane>

    """
    return _StepToGeom.steptogeom_MakePlane(*args)

def steptogeom_MakePolyline(*args) -> "opencascade::handle< Geom_BSplineCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SPL: StepGeom_Polyline

    Returns
    -------
    opencascade::handle<Geom_BSplineCurve>

    """
    return _StepToGeom.steptogeom_MakePolyline(*args)

def steptogeom_MakePolyline2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SPL: StepGeom_Polyline

    Returns
    -------
    opencascade::handle<Geom2d_BSplineCurve>

    """
    return _StepToGeom.steptogeom_MakePolyline2d(*args)

def steptogeom_MakeRectangularTrimmedSurface(*args) -> "opencascade::handle< Geom_RectangularTrimmedSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_RectangularTrimmedSurface

    Returns
    -------
    opencascade::handle<Geom_RectangularTrimmedSurface>

    """
    return _StepToGeom.steptogeom_MakeRectangularTrimmedSurface(*args)

def steptogeom_MakeSphericalSurface(*args) -> "opencascade::handle< Geom_SphericalSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_SphericalSurface

    Returns
    -------
    opencascade::handle<Geom_SphericalSurface>

    """
    return _StepToGeom.steptogeom_MakeSphericalSurface(*args)

def steptogeom_MakeSurface(*args) -> "opencascade::handle< Geom_Surface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_Surface

    Returns
    -------
    opencascade::handle<Geom_Surface>

    """
    return _StepToGeom.steptogeom_MakeSurface(*args)

def steptogeom_MakeSurfaceOfLinearExtrusion(*args) -> "opencascade::handle< Geom_SurfaceOfLinearExtrusion >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_SurfaceOfLinearExtrusion

    Returns
    -------
    opencascade::handle<Geom_SurfaceOfLinearExtrusion>

    """
    return _StepToGeom.steptogeom_MakeSurfaceOfLinearExtrusion(*args)

def steptogeom_MakeSurfaceOfRevolution(*args) -> "opencascade::handle< Geom_SurfaceOfRevolution >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_SurfaceOfRevolution

    Returns
    -------
    opencascade::handle<Geom_SurfaceOfRevolution>

    """
    return _StepToGeom.steptogeom_MakeSurfaceOfRevolution(*args)

def steptogeom_MakeSweptSurface(*args) -> "opencascade::handle< Geom_SweptSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_SweptSurface

    Returns
    -------
    opencascade::handle<Geom_SweptSurface>

    """
    return _StepToGeom.steptogeom_MakeSweptSurface(*args)

def steptogeom_MakeToroidalSurface(*args) -> "opencascade::handle< Geom_ToroidalSurface >":
    r"""
    No available documentation.

    Parameters
    ----------
    SS: StepGeom_ToroidalSurface

    Returns
    -------
    opencascade::handle<Geom_ToroidalSurface>

    """
    return _StepToGeom.steptogeom_MakeToroidalSurface(*args)

def steptogeom_MakeTransformation2d(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    SCTO: StepGeom_CartesianTransformationOperator2d
    CT: gp_Trsf2d

    Returns
    -------
    bool

    """
    return _StepToGeom.steptogeom_MakeTransformation2d(*args)

def steptogeom_MakeTransformation3d(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    SCTO: StepGeom_CartesianTransformationOperator3d
    CT: gp_Trsf

    Returns
    -------
    bool

    """
    return _StepToGeom.steptogeom_MakeTransformation3d(*args)

def steptogeom_MakeTrimmedCurve(*args) -> "opencascade::handle< Geom_TrimmedCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_TrimmedCurve

    Returns
    -------
    opencascade::handle<Geom_TrimmedCurve>

    """
    return _StepToGeom.steptogeom_MakeTrimmedCurve(*args)

def steptogeom_MakeTrimmedCurve2d(*args) -> "opencascade::handle< Geom2d_BSplineCurve >":
    r"""
    No available documentation.

    Parameters
    ----------
    SC: StepGeom_TrimmedCurve

    Returns
    -------
    opencascade::handle<Geom2d_BSplineCurve>

    """
    return _StepToGeom.steptogeom_MakeTrimmedCurve2d(*args)

def steptogeom_MakeVectorWithMagnitude(*args) -> "opencascade::handle< Geom_VectorWithMagnitude >":
    r"""
    No available documentation.

    Parameters
    ----------
    SV: StepGeom_Vector

    Returns
    -------
    opencascade::handle<Geom_VectorWithMagnitude>

    """
    return _StepToGeom.steptogeom_MakeVectorWithMagnitude(*args)

def steptogeom_MakeVectorWithMagnitude2d(*args) -> "opencascade::handle< Geom2d_VectorWithMagnitude >":
    r"""
    No available documentation.

    Parameters
    ----------
    SV: StepGeom_Vector

    Returns
    -------
    opencascade::handle<Geom2d_VectorWithMagnitude>

    """
    return _StepToGeom.steptogeom_MakeVectorWithMagnitude2d(*args)





