# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XmlMXCAFDoc module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xmlmxcafdoc.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XmlMXCAFDoc
else:
    import _XmlMXCAFDoc

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XmlMXCAFDoc.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XmlMXCAFDoc.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMXCAFDoc.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XmlMXCAFDoc.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XmlMXCAFDoc.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XmlMXCAFDoc.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XmlMXCAFDoc.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XmlMXCAFDoc.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XmlMXCAFDoc.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XmlMXCAFDoc.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMXCAFDoc.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMXCAFDoc.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XmlMXCAFDoc.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMXCAFDoc.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XmlMXCAFDoc.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XmlMXCAFDoc.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XmlMXCAFDoc.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XmlMXCAFDoc:
_XmlMXCAFDoc.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XmlMXCAFDoc.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.XmlMDF
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TDF
import OCC.Core.XmlObjMgt
import OCC.Core.LDOM
import OCC.Core.gp
import OCC.Core.Storage
import OCC.Core.TopTools
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_XmlMXCAFDoc_AssemblyItemRefDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_AssemblyItemRefDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_AssemblyItemRefDriver_Create()

def Handle_XmlMXCAFDoc_AssemblyItemRefDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_AssemblyItemRefDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_AssemblyItemRefDriver_DownCast(t)

def Handle_XmlMXCAFDoc_AssemblyItemRefDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_AssemblyItemRefDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_AssemblyItemRefDriver_IsNull(t)

def Handle_XmlMXCAFDoc_CentroidDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_CentroidDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_CentroidDriver_Create()

def Handle_XmlMXCAFDoc_CentroidDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_CentroidDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_CentroidDriver_DownCast(t)

def Handle_XmlMXCAFDoc_CentroidDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_CentroidDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_CentroidDriver_IsNull(t)

def Handle_XmlMXCAFDoc_ColorDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_ColorDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_ColorDriver_Create()

def Handle_XmlMXCAFDoc_ColorDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_ColorDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_ColorDriver_DownCast(t)

def Handle_XmlMXCAFDoc_ColorDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_ColorDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_ColorDriver_IsNull(t)

def Handle_XmlMXCAFDoc_DatumDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_DatumDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DatumDriver_Create()

def Handle_XmlMXCAFDoc_DatumDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_DatumDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DatumDriver_DownCast(t)

def Handle_XmlMXCAFDoc_DatumDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_DatumDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DatumDriver_IsNull(t)

def Handle_XmlMXCAFDoc_DimTolDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_DimTolDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DimTolDriver_Create()

def Handle_XmlMXCAFDoc_DimTolDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_DimTolDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DimTolDriver_DownCast(t)

def Handle_XmlMXCAFDoc_DimTolDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_DimTolDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_DimTolDriver_IsNull(t)

def Handle_XmlMXCAFDoc_GraphNodeDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_GraphNodeDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_GraphNodeDriver_Create()

def Handle_XmlMXCAFDoc_GraphNodeDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_GraphNodeDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_GraphNodeDriver_DownCast(t)

def Handle_XmlMXCAFDoc_GraphNodeDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_GraphNodeDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_GraphNodeDriver_IsNull(t)

def Handle_XmlMXCAFDoc_LocationDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_LocationDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_LocationDriver_Create()

def Handle_XmlMXCAFDoc_LocationDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_LocationDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_LocationDriver_DownCast(t)

def Handle_XmlMXCAFDoc_LocationDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_LocationDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_LocationDriver_IsNull(t)

def Handle_XmlMXCAFDoc_MaterialDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_MaterialDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_MaterialDriver_Create()

def Handle_XmlMXCAFDoc_MaterialDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_MaterialDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_MaterialDriver_DownCast(t)

def Handle_XmlMXCAFDoc_MaterialDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_MaterialDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_MaterialDriver_IsNull(t)

def Handle_XmlMXCAFDoc_NoteDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_NoteDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteDriver_Create()

def Handle_XmlMXCAFDoc_NoteDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_NoteDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteDriver_DownCast(t)

def Handle_XmlMXCAFDoc_NoteDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_NoteDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteDriver_IsNull(t)

def Handle_XmlMXCAFDoc_VisMaterialDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_VisMaterialDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialDriver_Create()

def Handle_XmlMXCAFDoc_VisMaterialDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_VisMaterialDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialDriver_DownCast(t)

def Handle_XmlMXCAFDoc_VisMaterialDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_VisMaterialDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialDriver_IsNull(t)

def Handle_XmlMXCAFDoc_VisMaterialToolDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_VisMaterialToolDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialToolDriver_Create()

def Handle_XmlMXCAFDoc_VisMaterialToolDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_VisMaterialToolDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialToolDriver_DownCast(t)

def Handle_XmlMXCAFDoc_VisMaterialToolDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_VisMaterialToolDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_VisMaterialToolDriver_IsNull(t)

def Handle_XmlMXCAFDoc_NoteBinDataDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_NoteBinDataDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteBinDataDriver_Create()

def Handle_XmlMXCAFDoc_NoteBinDataDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_NoteBinDataDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteBinDataDriver_DownCast(t)

def Handle_XmlMXCAFDoc_NoteBinDataDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_NoteBinDataDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteBinDataDriver_IsNull(t)

def Handle_XmlMXCAFDoc_NoteCommentDriver_Create() -> "opencascade::handle< XmlMXCAFDoc_NoteCommentDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteCommentDriver_Create()

def Handle_XmlMXCAFDoc_NoteCommentDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XmlMXCAFDoc_NoteCommentDriver >":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteCommentDriver_DownCast(t)

def Handle_XmlMXCAFDoc_NoteCommentDriver_IsNull(t: "opencascade::handle< XmlMXCAFDoc_NoteCommentDriver > const &") -> "bool":
    return _XmlMXCAFDoc.Handle_XmlMXCAFDoc_NoteCommentDriver_IsNull(t)
class xmlmxcafdoc(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        Adds the attribute drivers to <adrivertable>.

        Parameters
        ----------
        aDriverTable: XmlMDF_ADriverTable
        anMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.xmlmxcafdoc_AddDrivers(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _XmlMXCAFDoc.xmlmxcafdoc_swiginit(self, _XmlMXCAFDoc.new_xmlmxcafdoc())
    __swig_destroy__ = _XmlMXCAFDoc.delete_xmlmxcafdoc

# Register xmlmxcafdoc in _XmlMXCAFDoc:
_XmlMXCAFDoc.xmlmxcafdoc_swigregister(xmlmxcafdoc)

def xmlmxcafdoc_AddDrivers(*args) -> "void":
    r"""
    Adds the attribute drivers to <adrivertable>.

    Parameters
    ----------
    aDriverTable: XmlMDF_ADriverTable
    anMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _XmlMXCAFDoc.xmlmxcafdoc_AddDrivers(*args)

class XmlMXCAFDoc_AssemblyItemRefDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_AssemblyItemRefDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_AssemblyItemRefDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_AssemblyItemRefDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_AssemblyItemRefDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_AssemblyItemRefDriver

# Register XmlMXCAFDoc_AssemblyItemRefDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_AssemblyItemRefDriver_swigregister(XmlMXCAFDoc_AssemblyItemRefDriver)

class XmlMXCAFDoc_CentroidDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_CentroidDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_CentroidDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_CentroidDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_CentroidDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_CentroidDriver

# Register XmlMXCAFDoc_CentroidDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_CentroidDriver_swigregister(XmlMXCAFDoc_CentroidDriver)

class XmlMXCAFDoc_ColorDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_ColorDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_ColorDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_ColorDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_ColorDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_ColorDriver

# Register XmlMXCAFDoc_ColorDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_ColorDriver_swigregister(XmlMXCAFDoc_ColorDriver)

class XmlMXCAFDoc_DatumDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_DatumDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_DatumDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_DatumDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_DatumDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_DatumDriver

# Register XmlMXCAFDoc_DatumDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_DatumDriver_swigregister(XmlMXCAFDoc_DatumDriver)

class XmlMXCAFDoc_DimTolDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_DimTolDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_DimTolDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_DimTolDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_DimTolDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_DimTolDriver

# Register XmlMXCAFDoc_DimTolDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_DimTolDriver_swigregister(XmlMXCAFDoc_DimTolDriver)

class XmlMXCAFDoc_GraphNodeDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_GraphNodeDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_GraphNodeDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_GraphNodeDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_GraphNodeDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_GraphNodeDriver

# Register XmlMXCAFDoc_GraphNodeDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_GraphNodeDriver_swigregister(XmlMXCAFDoc_GraphNodeDriver)

class XmlMXCAFDoc_LocationDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_LocationDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_LocationDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_LocationDriver_Paste(self, *args)

    def SetSharedLocations(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theLocations: TopTools_LocationSetPtr

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_LocationDriver_SetSharedLocations(self, *args)

    def Translate(self, *args) -> "Standard_Boolean":
        r"""
        Translate a non storable location to a storable location.

        Parameters
        ----------
        theLoc: TopLoc_Location
        theParent: XmlObjMgt_Element
        theMap: XmlObjMgt_SRelocationTable

        Returns
        -------
        None
        Translate a storable location to a non storable location.

        Parameters
        ----------
        theParent: XmlObjMgt_Element
        theLoc: TopLoc_Location
        theMap: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_LocationDriver_Translate(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_LocationDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_LocationDriver

# Register XmlMXCAFDoc_LocationDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_LocationDriver_swigregister(XmlMXCAFDoc_LocationDriver)

class XmlMXCAFDoc_MaterialDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_MaterialDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_MaterialDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: XmlObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: XmlObjMgt_Persistent
        RelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_MaterialDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_MaterialDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_MaterialDriver

# Register XmlMXCAFDoc_MaterialDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_MaterialDriver_swigregister(XmlMXCAFDoc_MaterialDriver)

class XmlMXCAFDoc_NoteDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_NoteDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_NoteDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_NoteDriver

# Register XmlMXCAFDoc_NoteDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_NoteDriver_swigregister(XmlMXCAFDoc_NoteDriver)

class XmlMXCAFDoc_VisMaterialDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Main constructor.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_VisMaterialDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Paste attribute from persistence into document.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Paste attribute from document into persistence.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_VisMaterialDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_VisMaterialDriver

# Register XmlMXCAFDoc_VisMaterialDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialDriver_swigregister(XmlMXCAFDoc_VisMaterialDriver)

class XmlMXCAFDoc_VisMaterialToolDriver(OCC.Core.XmlMDF.XmlMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Main constructor.

        Parameters
        ----------
        theMsgDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialToolDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_VisMaterialToolDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        Paste attribute from persistence into document.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        Paste attribute from document into persistence.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialToolDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_VisMaterialToolDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_VisMaterialToolDriver

# Register XmlMXCAFDoc_VisMaterialToolDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_VisMaterialToolDriver_swigregister(XmlMXCAFDoc_VisMaterialToolDriver)

class XmlMXCAFDoc_NoteBinDataDriver(XmlMXCAFDoc_NoteDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_NoteBinDataDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_NoteBinDataDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_NoteBinDataDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_NoteBinDataDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_NoteBinDataDriver

# Register XmlMXCAFDoc_NoteBinDataDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_NoteBinDataDriver_swigregister(XmlMXCAFDoc_NoteBinDataDriver)

class XmlMXCAFDoc_NoteCommentDriver(XmlMXCAFDoc_NoteDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _XmlMXCAFDoc.XmlMXCAFDoc_NoteCommentDriver_swiginit(self, _XmlMXCAFDoc.new_XmlMXCAFDoc_NoteCommentDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: XmlObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: XmlObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: XmlObjMgt_Persistent
        theRelocTable: XmlObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _XmlMXCAFDoc.XmlMXCAFDoc_NoteCommentDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XmlMXCAFDoc_NoteCommentDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XmlMXCAFDoc.delete_XmlMXCAFDoc_NoteCommentDriver

# Register XmlMXCAFDoc_NoteCommentDriver in _XmlMXCAFDoc:
_XmlMXCAFDoc.XmlMXCAFDoc_NoteCommentDriver_swigregister(XmlMXCAFDoc_NoteCommentDriver)





