# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TColGeom2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_tcolgeom2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TColGeom2d
else:
    import _TColGeom2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TColGeom2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TColGeom2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TColGeom2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TColGeom2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TColGeom2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TColGeom2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TColGeom2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TColGeom2d:
_TColGeom2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TColGeom2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TColGeom2d_HArray1OfCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_Create()

def Handle_TColGeom2d_HArray1OfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfCurve_IsNull(t)

def Handle_TColGeom2d_HArray1OfBezierCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfBezierCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_Create()

def Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfBezierCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfBezierCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfBezierCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBezierCurve_IsNull(t)

def Handle_TColGeom2d_HArray1OfBSplineCurve_Create() -> "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_Create()

def Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t)

def Handle_TColGeom2d_HArray1OfBSplineCurve_IsNull(t: "opencascade::handle< TColGeom2d_HArray1OfBSplineCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HArray1OfBSplineCurve_IsNull(t)

def Handle_TColGeom2d_HSequenceOfBoundedCurve_Create() -> "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_Create()

def Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t)

def Handle_TColGeom2d_HSequenceOfBoundedCurve_IsNull(t: "opencascade::handle< TColGeom2d_HSequenceOfBoundedCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfBoundedCurve_IsNull(t)

def Handle_TColGeom2d_HSequenceOfCurve_Create() -> "opencascade::handle< TColGeom2d_HSequenceOfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_Create()

def Handle_TColGeom2d_HSequenceOfCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TColGeom2d_HSequenceOfCurve >":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_DownCast(t)

def Handle_TColGeom2d_HSequenceOfCurve_IsNull(t: "opencascade::handle< TColGeom2d_HSequenceOfCurve > const &") -> "bool":
    return _TColGeom2d.Handle_TColGeom2d_HSequenceOfCurve_IsNull(t)
class TColGeom2d_Array1OfBSplineCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfBSplineCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_BSplineCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfBSplineCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_BSplineCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BSplineCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBSplineCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfBSplineCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfBSplineCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfBSplineCurve_swigregister(TColGeom2d_Array1OfBSplineCurve)

class TColGeom2d_Array1OfBezierCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfBezierCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfBezierCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_BezierCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfBezierCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_BezierCurve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BezierCurve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BezierCurve > &":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BezierCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfBezierCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfBezierCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfBezierCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfBezierCurve_swigregister(TColGeom2d_Array1OfBezierCurve)

class TColGeom2d_Array1OfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_Array1OfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_Array1OfCurve(*args))

    def Init(self, theValue: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_IsAllocated(self)

    def Assign(self, theOther: "TColGeom2d_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Assign(self, theOther)

    def Move(self, theOther: "TColGeom2d_Array1OfCurve") -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Set(self, *args)

    def First(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_Array1OfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _TColGeom2d.TColGeom2d_Array1OfCurve_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_Array1OfCurve

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register TColGeom2d_Array1OfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_Array1OfCurve_swigregister(TColGeom2d_Array1OfCurve)

class TColGeom2d_SequenceOfBoundedCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfBoundedCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfBoundedCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_BoundedCurve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfBoundedCurve") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BoundedCurve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_BoundedCurve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_BoundedCurve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfBoundedCurve

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfBoundedCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_swigregister(TColGeom2d_SequenceOfBoundedCurve)

def TColGeom2d_SequenceOfBoundedCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfBoundedCurve_delNode(theNode, theAl)

class TColGeom2d_SequenceOfCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfCurve(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfCurve") -> "NCollection_Sequence< opencascade::handle< Geom2d_Curve > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfCurve") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Curve > &":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Curve > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfCurve_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfCurve

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfCurve_swigregister(TColGeom2d_SequenceOfCurve)

def TColGeom2d_SequenceOfCurve_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfCurve_delNode(theNode, theAl)

class TColGeom2d_SequenceOfGeometry(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > >::const_iterator":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_cend(self)

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_SequenceOfGeometry_swiginit(self, _TColGeom2d.new_TColGeom2d_SequenceOfGeometry(*args))

    def Size(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Clear(self, theAllocator)

    def Assign(self, theOther: "TColGeom2d_SequenceOfGeometry") -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Assign(self, theOther)

    def Set(self, theOther: "TColGeom2d_SequenceOfGeometry") -> "NCollection_Sequence< opencascade::handle< Geom2d_Geometry > > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TColGeom2d_SequenceOfGeometry") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Geometry > const &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Geom2d_Geometry > &":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Geom2d_Geometry > const &") -> "void":
        return _TColGeom2d.TColGeom2d_SequenceOfGeometry_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_SequenceOfGeometry

    def __len__(self):
        return self.Size()


# Register TColGeom2d_SequenceOfGeometry in _TColGeom2d:
_TColGeom2d.TColGeom2d_SequenceOfGeometry_swigregister(TColGeom2d_SequenceOfGeometry)

def TColGeom2d_SequenceOfGeometry_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TColGeom2d.TColGeom2d_SequenceOfGeometry_delNode(theNode, theAl)

class TColGeom2d_HArray1OfCurve(TColGeom2d_Array1OfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfCurve

# Register TColGeom2d_HArray1OfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfCurve_swigregister(TColGeom2d_HArray1OfCurve)

class TColGeom2d_HArray1OfBezierCurve(TColGeom2d_Array1OfBezierCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfBezierCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfBezierCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfBezierCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfBezierCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfBezierCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfBezierCurve

# Register TColGeom2d_HArray1OfBezierCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfBezierCurve_swigregister(TColGeom2d_HArray1OfBezierCurve)

class TColGeom2d_HArray1OfBSplineCurve(TColGeom2d_Array1OfBSplineCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HArray1OfBSplineCurve(*args))

    def Array1(self) -> "TColGeom2d_Array1OfBSplineCurve const &":
        return _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_Array1(self)

    def ChangeArray1(self) -> "TColGeom2d_Array1OfBSplineCurve &":
        return _TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HArray1OfBSplineCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HArray1OfBSplineCurve

# Register TColGeom2d_HArray1OfBSplineCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HArray1OfBSplineCurve_swigregister(TColGeom2d_HArray1OfBSplineCurve)

class TColGeom2d_HSequenceOfBoundedCurve(TColGeom2d_SequenceOfBoundedCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HSequenceOfBoundedCurve(*args))

    def Sequence(self) -> "TColGeom2d_SequenceOfBoundedCurve const &":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom2d_SequenceOfBoundedCurve &":
        return _TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HSequenceOfBoundedCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HSequenceOfBoundedCurve

# Register TColGeom2d_HSequenceOfBoundedCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HSequenceOfBoundedCurve_swigregister(TColGeom2d_HSequenceOfBoundedCurve)

class TColGeom2d_HSequenceOfCurve(TColGeom2d_SequenceOfCurve, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TColGeom2d.TColGeom2d_HSequenceOfCurve_swiginit(self, _TColGeom2d.new_TColGeom2d_HSequenceOfCurve(*args))

    def Sequence(self) -> "TColGeom2d_SequenceOfCurve const &":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_Sequence(self)

    def Append(self, *args) -> "void":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_Append(self, *args)

    def ChangeSequence(self) -> "TColGeom2d_SequenceOfCurve &":
        return _TColGeom2d.TColGeom2d_HSequenceOfCurve_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TColGeom2d_HSequenceOfCurve_DownCast(t)

    __swig_destroy__ = _TColGeom2d.delete_TColGeom2d_HSequenceOfCurve

# Register TColGeom2d_HSequenceOfCurve in _TColGeom2d:
_TColGeom2d.TColGeom2d_HSequenceOfCurve_swigregister(TColGeom2d_HSequenceOfCurve)





