# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IntAna2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intana2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IntAna2d
else:
    import _IntAna2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IntAna2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IntAna2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IntAna2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IntAna2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntAna2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntAna2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IntAna2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IntAna2d:
_IntAna2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IntAna2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *



class IntAna2d_AnaIntersection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor. isdone returns false.

        Returns
        -------
        None
        Intersection between two lines.

        Parameters
        ----------
        L1: gp_Lin2d
        L2: gp_Lin2d

        Returns
        -------
        None
        Intersection between two circles.

        Parameters
        ----------
        C1: gp_Circ2d
        C2: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a circle.

        Parameters
        ----------
        L: gp_Lin2d
        C: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a conic.

        Parameters
        ----------
        L: gp_Lin2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a circle and another conic.

        Parameters
        ----------
        C: gp_Circ2d
        Co: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an ellipse and another conic.

        Parameters
        ----------
        E: gp_Elips2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a parabola and another conic.

        Parameters
        ----------
        P: gp_Parab2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an hyperbola and another conic.

        Parameters
        ----------
        H: gp_Hypr2d
        C: IntAna2d_Conic

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_AnaIntersection_swiginit(self, _IntAna2d.new_IntAna2d_AnaIntersection(*args))

    def IdenticalElements(self, *args) -> "Standard_Boolean":
        r"""
        For the intersection between an element of gp and a conic known by an implicit equation, the result will be true if the element of gp verifies the implicit equation. for the intersection between two lin2d or two circ2d, the result will be true if the elements are identical. the function returns false in all the other cases.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IdenticalElements(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was succesfull.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IsDone(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when there is no intersection, i-e - no intersection point - the elements are not identical. the element may be parallel in this case.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_IsEmpty(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intpoint between the 2 curves.

        Returns
        -------
        int

        """
        return _IntAna2d.IntAna2d_AnaIntersection_NbPoints(self, *args)

    def ParallelElements(self, *args) -> "Standard_Boolean":
        r"""
        For the intersection between two lin2d or two circ2d, the function returns true if the elements are parallel. the function returns false in all the other cases.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_AnaIntersection_ParallelElements(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Intersection between two lines.

        Parameters
        ----------
        L1: gp_Lin2d
        L2: gp_Lin2d

        Returns
        -------
        None
        Intersection between two circles.

        Parameters
        ----------
        C1: gp_Circ2d
        C2: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a circle.

        Parameters
        ----------
        L: gp_Lin2d
        C: gp_Circ2d

        Returns
        -------
        None
        Intersection between a line and a conic.

        Parameters
        ----------
        L: gp_Lin2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a circle and another conic.

        Parameters
        ----------
        C: gp_Circ2d
        Co: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an ellipse and another conic.

        Parameters
        ----------
        E: gp_Elips2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between a parabola and another conic.

        Parameters
        ----------
        P: gp_Parab2d
        C: IntAna2d_Conic

        Returns
        -------
        None
        Intersection between an hyperbola and another conic.

        Parameters
        ----------
        H: gp_Hypr2d
        C: IntAna2d_Conic

        Returns
        -------
        None

        """
        return _IntAna2d.IntAna2d_AnaIntersection_Perform(self, *args)

    def Point(self, *args) -> "IntAna2d_IntPoint const &":
        r"""
        Returns the intersection point of range n; if (n<=0) or (n>nbpoints), an exception is raised.

        Parameters
        ----------
        N: int

        Returns
        -------
        IntAna2d_IntPoint

        """
        return _IntAna2d.IntAna2d_AnaIntersection_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_AnaIntersection

# Register IntAna2d_AnaIntersection in _IntAna2d:
_IntAna2d.IntAna2d_AnaIntersection_swigregister(IntAna2d_AnaIntersection)

class IntAna2d_Conic(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: gp_Circ2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Lin2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Parab2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Hypr2d

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: gp_Elips2d

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_Conic_swiginit(self, _IntAna2d.new_IntAna2d_Conic(*args))

    def Coefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation wich defines the conic: a.x**2 + b.y**2 + 2.c.x*y + 2.d.x + 2.e.y + f = 0.

        Parameters
        ----------

        Returns
        -------
        A: float
        B: float
        C: float
        D: float
        E: float
        F: float

        """
        return _IntAna2d.IntAna2d_Conic_Coefficients(self, *args)

    def Grad(self, *args) -> "gp_XY":
        r"""
        Returns the value of the gradient of f at the point x,y.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        gp_XY

        """
        return _IntAna2d.IntAna2d_Conic_Grad(self, *args)

    def NewCoefficients(self, *args) -> "void":
        r"""
        Returns the coefficients of the polynomial equation ( written in the natural coordinates system ) a x x + b y y + 2 c x y + 2 d x + 2 e y + f in the local coordinates system defined by axis.

        Parameters
        ----------
        Axis: gp_Ax2d

        Returns
        -------
        A: float
        B: float
        C: float
        D: float
        E: float
        F: float

        """
        return _IntAna2d.IntAna2d_Conic_NewCoefficients(self, *args)

    def ValAndGrad(self, *args) -> "void":
        r"""
        Returns the value of the function and its gradient at the point x,y.

        Parameters
        ----------
        X: float
        Y: float
        Grd: gp_XY

        Returns
        -------
        Val: float

        """
        return _IntAna2d.IntAna2d_Conic_ValAndGrad(self, *args)

    def Value(self, *args) -> "Standard_Real":
        r"""
        Value of the function f at the point x,y.

        Parameters
        ----------
        X: float
        Y: float

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_Conic_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_Conic

# Register IntAna2d_Conic in _IntAna2d:
_IntAna2d.IntAna2d_Conic_swigregister(IntAna2d_Conic)

class IntAna2d_IntPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an intersection point between 2 parametric 2d lines. x,y are the coordinate of the point. u1 is the parameter on the first element, u2 the parameter on the second one.

        Parameters
        ----------
        X: float
        Y: float
        U1: float
        U2: float

        Returns
        -------
        None
        Create an intersection point between a parametric 2d line, and a line given by an implicit equation (implicitcurve). x,y are the coordinate of the point. u1 is the parameter on the parametric element. empty constructor. it's necessary to use one of the setvalue method after this one.

        Parameters
        ----------
        X: float
        Y: float
        U1: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        None

        """
        _IntAna2d.IntAna2d_IntPoint_swiginit(self, _IntAna2d.new_IntAna2d_IntPoint(*args))

    def ParamOnFirst(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the first element.

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_IntPoint_ParamOnFirst(self, *args)

    def ParamOnSecond(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the second element. if the second element is an implicit curve, an exception is raised.

        Returns
        -------
        float

        """
        return _IntAna2d.IntAna2d_IntPoint_ParamOnSecond(self, *args)

    def SecondIsImplicit(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the second curve is implicit.

        Returns
        -------
        bool

        """
        return _IntAna2d.IntAna2d_IntPoint_SecondIsImplicit(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Set the values for a 'non-implicit' point.

        Parameters
        ----------
        X: float
        Y: float
        U1: float
        U2: float

        Returns
        -------
        None
        Set the values for an 'implicit' point.

        Parameters
        ----------
        X: float
        Y: float
        U1: float

        Returns
        -------
        None

        """
        return _IntAna2d.IntAna2d_IntPoint_SetValue(self, *args)

    def Value(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the geometric point.

        Returns
        -------
        gp_Pnt2d

        """
        return _IntAna2d.IntAna2d_IntPoint_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntAna2d.delete_IntAna2d_IntPoint

# Register IntAna2d_IntPoint in _IntAna2d:
_IntAna2d.IntAna2d_IntPoint_swigregister(IntAna2d_IntPoint)





