# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Geom2dLProp module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geom2dlprop.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Geom2dLProp
else:
    import _Geom2dLProp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Geom2dLProp.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Geom2dLProp.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Geom2dLProp.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dLProp.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dLProp.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dLProp.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dLProp.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Geom2dLProp.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Geom2dLProp:
_Geom2dLProp.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Geom2dLProp.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.LProp
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *



class Geom2dLProp_CLProps2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the local properties of the curve <c> the current point and the derivatives are computed at the same time, which allows an optimization of the computation time. <n> indicates the maximum number of derivations to be done (0, 1, 2 or 3). for example, to compute only the tangent, n should be equal to 1. <resolution> is the linear tolerance (it is used to test if a vector is null).

        Parameters
        ----------
        C: Geom2d_Curve
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u>. all the computations done will be related to <c> and <u>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        N: int
        Resolution: float

        Returns
        -------
        None
        Same as previous constructor but here the parameter is set to the value <u> and the curve is set with setcurve. the curve can have a empty constructor all the computations done will be related to <c> and <u> when the functions 'set' will be done.

        Parameters
        ----------
        N: int
        Resolution: float

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_CLProps2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_CLProps2d(*args))

    def CentreOfCurvature(self, *args) -> "void":
        r"""
        Returns the centre of curvature <p>.

        Parameters
        ----------
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_CentreOfCurvature(self, *args)

    def Curvature(self, *args) -> "Standard_Real":
        r"""
        Returns the curvature.

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Curvature(self, *args)

    def D1(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the first derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D1(self, *args)

    def D2(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the second derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D2(self, *args)

    def D3(self, *args) -> "gp_Vec2d const":
        r"""
        Returns the third derivative. the derivative is computed if it has not been yet.

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_D3(self, *args)

    def IsTangentDefined(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the tangent is defined. for example, the tangent is not defined if the three first derivatives are all null.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_IsTangentDefined(self, *args)

    def Normal(self, *args) -> "void":
        r"""
        Returns the normal direction <n>.

        Parameters
        ----------
        N: gp_Dir2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Normal(self, *args)

    def SetCurve(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the new curve.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_SetCurve(self, *args)

    def SetParameter(self, *args) -> "void":
        r"""
        Initializes the local properties of the curve for the parameter value <u>.

        Parameters
        ----------
        U: float

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_SetParameter(self, *args)

    def Tangent(self, *args) -> "void":
        r"""
        Output the tangent direction <d>.

        Parameters
        ----------
        D: gp_Dir2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Tangent(self, *args)

    def Value(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the point.

        Returns
        -------
        gp_Pnt2d

        """
        return _Geom2dLProp.Geom2dLProp_CLProps2d_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_CLProps2d

# Register Geom2dLProp_CLProps2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_CLProps2d_swigregister(Geom2dLProp_CLProps2d)

class Geom2dLProp_CurAndInf2d(OCC.Core.LProp.LProp_CurAndInf):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the framework. note: the curve on which the local properties are computed is defined using one of the following functions: perform, performcurext or performinf.

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_CurAndInf2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_CurAndInf2d(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the solutions are found.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_IsDone(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        For the curve c, computes both the inflection points and the maximum and minimum curvatures.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_Perform(self, *args)

    def PerformCurExt(self, *args) -> "void":
        r"""
        For the curve c, computes the locals extremas of curvature.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_PerformCurExt(self, *args)

    def PerformInf(self, *args) -> "void":
        r"""
        For the curve c, computes the inflections. after computation, the following functions can be used: - isdone to check if the computation was successful - nbpoints to obtain the number of computed particular points - parameter to obtain the parameter on the curve for each particular point - type to check if the point is an inflection point or an extremum of curvature of the curve c. warning these functions can be used to analyze a series of curves, however it is necessary to clear the table of results between each computation.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_CurAndInf2d_PerformInf(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_CurAndInf2d

# Register Geom2dLProp_CurAndInf2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_CurAndInf2d_swigregister(Geom2dLProp_CurAndInf2d)

class Geom2dLProp_Curve2dTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Continuity(*args) -> "Standard_Integer":
        r"""
        Returns the order of continuity of the curve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        int

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_Continuity(*args)

    @staticmethod
    def D1(*args) -> "void":
        r"""
        Computes the point <p> and first derivative <v1> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D1(*args)

    @staticmethod
    def D2(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D2(*args)

    @staticmethod
    def D3(*args) -> "void":
        r"""
        Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d
        V1: gp_Vec2d
        V2: gp_Vec2d
        V3: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_D3(*args)

    @staticmethod
    def FirstParameter(*args) -> "Standard_Real":
        r"""
        Returns the first parameter bound of the curve.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_FirstParameter(*args)

    @staticmethod
    def LastParameter(*args) -> "Standard_Real":
        r"""
        Returns the last parameter bound of the curve. firstparameter must be less than lastparameter.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        float

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_LastParameter(*args)

    @staticmethod
    def Value(*args) -> "void":
        r"""
        Computes the point <p> of parameter <u> on the curve <c>.

        Parameters
        ----------
        C: Geom2d_Curve
        U: float
        P: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_Curve2dTool_Value(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _Geom2dLProp.Geom2dLProp_Curve2dTool_swiginit(self, _Geom2dLProp.new_Geom2dLProp_Curve2dTool())
    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_Curve2dTool

# Register Geom2dLProp_Curve2dTool in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_Curve2dTool_swigregister(Geom2dLProp_Curve2dTool)

def Geom2dLProp_Curve2dTool_Continuity(*args) -> "Standard_Integer":
    r"""
    Returns the order of continuity of the curve <c>. returns 1 : first derivative only is computable returns 2 : first and second derivative only are computable. returns 3 : first, second and third are computable.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    int

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_Continuity(*args)

def Geom2dLProp_Curve2dTool_D1(*args) -> "void":
    r"""
    Computes the point <p> and first derivative <v1> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D1(*args)

def Geom2dLProp_Curve2dTool_D2(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1> and second derivative <v2> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d
    V2: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D2(*args)

def Geom2dLProp_Curve2dTool_D3(*args) -> "void":
    r"""
    Computes the point <p>, the first derivative <v1>, the second derivative <v2> and third derivative <v3> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d
    V1: gp_Vec2d
    V2: gp_Vec2d
    V3: gp_Vec2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_D3(*args)

def Geom2dLProp_Curve2dTool_FirstParameter(*args) -> "Standard_Real":
    r"""
    Returns the first parameter bound of the curve.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    float

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_FirstParameter(*args)

def Geom2dLProp_Curve2dTool_LastParameter(*args) -> "Standard_Real":
    r"""
    Returns the last parameter bound of the curve. firstparameter must be less than lastparameter.

    Parameters
    ----------
    C: Geom2d_Curve

    Returns
    -------
    float

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_LastParameter(*args)

def Geom2dLProp_Curve2dTool_Value(*args) -> "void":
    r"""
    Computes the point <p> of parameter <u> on the curve <c>.

    Parameters
    ----------
    C: Geom2d_Curve
    U: float
    P: gp_Pnt2d

    Returns
    -------
    None

    """
    return _Geom2dLProp.Geom2dLProp_Curve2dTool_Value(*args)

class Geom2dLProp_FuncCurExt(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve
        Tol: float

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_FuncCurExt_swiginit(self, _Geom2dLProp.new_Geom2dLProp_FuncCurExt(*args))

    def IsMinKC(self, *args) -> "Standard_Boolean":
        r"""
        True if param corresponds to a minus of the radius of curvature.

        Parameters
        ----------
        Param: float

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_FuncCurExt_IsMinKC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_FuncCurExt

# Register Geom2dLProp_FuncCurExt in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_FuncCurExt_swigregister(Geom2dLProp_FuncCurExt)

class Geom2dLProp_FuncCurNul(OCC.Core.math.math_FunctionWithDerivative):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom2d_Curve

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_FuncCurNul_swiginit(self, _Geom2dLProp.new_Geom2dLProp_FuncCurNul(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_FuncCurNul

# Register Geom2dLProp_FuncCurNul in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_FuncCurNul_swigregister(Geom2dLProp_FuncCurNul)

class Geom2dLProp_NumericCurInf2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _Geom2dLProp.Geom2dLProp_NumericCurInf2d_swiginit(self, _Geom2dLProp.new_Geom2dLProp_NumericCurInf2d(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the solutions are found.

        Returns
        -------
        bool

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_IsDone(self, *args)

    def PerformCurExt(self, *args) -> "void":
        r"""
        Computes the locals extremas of curvature.

        Parameters
        ----------
        C: Geom2d_Curve
        Result: LProp_CurAndInf

        Returns
        -------
        None
        Computes the locals extremas of curvature. in the interval of parmeters [umin,umax].

        Parameters
        ----------
        C: Geom2d_Curve
        UMin: float
        UMax: float
        Result: LProp_CurAndInf

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_PerformCurExt(self, *args)

    def PerformInf(self, *args) -> "void":
        r"""
        Computes the inflections.

        Parameters
        ----------
        C: Geom2d_Curve
        Result: LProp_CurAndInf

        Returns
        -------
        None
        Computes the inflections in the interval of parmeters [umin,umax].

        Parameters
        ----------
        C: Geom2d_Curve
        UMin: float
        UMax: float
        Result: LProp_CurAndInf

        Returns
        -------
        None

        """
        return _Geom2dLProp.Geom2dLProp_NumericCurInf2d_PerformInf(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dLProp.delete_Geom2dLProp_NumericCurInf2d

# Register Geom2dLProp_NumericCurInf2d in _Geom2dLProp:
_Geom2dLProp.Geom2dLProp_NumericCurInf2d_swigregister(Geom2dLProp_NumericCurInf2d)





