# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IGESCAFControl module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_igescafcontrol.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IGESCAFControl
else:
    import _IGESCAFControl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IGESCAFControl.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IGESCAFControl.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESCAFControl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESCAFControl.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IGESCAFControl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IGESCAFControl:
_IGESCAFControl.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IGESCAFControl.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Quantity
import OCC.Core.TCollection
import OCC.Core.IGESControl
import OCC.Core.Transfer
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Interface
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IGESToBRep
import OCC.Core.IGESData
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom
import OCC.Core.TopTools
import OCC.Core.Geom2d
import OCC.Core.XSControl
import OCC.Core.IFSelect
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *



class igescafcontrol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def DecodeColor(*args) -> "Quantity_Color":
        r"""
        Provides a tool for writing iges file converts iges color index to cascade color.

        Parameters
        ----------
        col: int

        Returns
        -------
        Quantity_Color

        """
        return _IGESCAFControl.igescafcontrol_DecodeColor(*args)

    @staticmethod
    def EncodeColor(*args) -> "Standard_Integer":
        r"""
        Tries to convert cascade color to iges color index if no corresponding color defined in iges, returns 0.

        Parameters
        ----------
        col: Quantity_Color

        Returns
        -------
        int

        """
        return _IGESCAFControl.igescafcontrol_EncodeColor(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _IGESCAFControl.igescafcontrol_swiginit(self, _IGESCAFControl.new_igescafcontrol())
    __swig_destroy__ = _IGESCAFControl.delete_igescafcontrol

# Register igescafcontrol in _IGESCAFControl:
_IGESCAFControl.igescafcontrol_swigregister(igescafcontrol)

def igescafcontrol_DecodeColor(*args) -> "Quantity_Color":
    r"""
    Provides a tool for writing iges file converts iges color index to cascade color.

    Parameters
    ----------
    col: int

    Returns
    -------
    Quantity_Color

    """
    return _IGESCAFControl.igescafcontrol_DecodeColor(*args)

def igescafcontrol_EncodeColor(*args) -> "Standard_Integer":
    r"""
    Tries to convert cascade color to iges color index if no corresponding color defined in iges, returns 0.

    Parameters
    ----------
    col: Quantity_Color

    Returns
    -------
    int

    """
    return _IGESCAFControl.igescafcontrol_EncodeColor(*args)

class IGESCAFControl_Reader(OCC.Core.IGESControl.IGESControl_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a reader with an empty iges model and sets colormode, layermode and namemode to standard_true.

        Returns
        -------
        None
        Creates a reader tool and attaches it to an already existing session clears the session if it was not yet set for iges.

        Parameters
        ----------
        theWS: XSControl_WorkSession
        FromScratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _IGESCAFControl.IGESCAFControl_Reader_swiginit(self, _IGESCAFControl.new_IGESCAFControl_Reader(*args))

    def GetColorMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetColorMode(self, *args)

    def GetLayerMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetLayerMode(self, *args)

    def GetNameMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetNameMode(self, *args)

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        theFileName: TCollection_AsciiString
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Translate iges file given by filename into the document return true if succeeded, and false in case of fail.

        Parameters
        ----------
        theFileName: char *
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_Perform(self, *args)

    def SetColorMode(self, *args) -> "void":
        r"""
        Set colormode for indicate read colors or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetColorMode(self, *args)

    def SetLayerMode(self, *args) -> "void":
        r"""
        Set layermode for indicate read layers or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetLayerMode(self, *args)

    def SetNameMode(self, *args) -> "void":
        r"""
        Set namemode for indicate read name or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetNameMode(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Translates currently loaded iges file into the document returns true if succeeded, and false in case of fail.

        Parameters
        ----------
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_Transfer(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESCAFControl.delete_IGESCAFControl_Reader

# Register IGESCAFControl_Reader in _IGESCAFControl:
_IGESCAFControl.IGESCAFControl_Reader_swigregister(IGESCAFControl_Reader)

class IGESCAFControl_Writer(OCC.Core.IGESControl.IGESControl_Writer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer with an empty iges model and sets colormode, layermode and namemode to standard_true.

        Returns
        -------
        None
        Creates a reader tool and attaches it to an already existing session clears the session if it was not yet set for iges.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _IGESCAFControl.IGESCAFControl_Writer_swiginit(self, _IGESCAFControl.new_IGESCAFControl_Writer(*args))

    def GetColorMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetColorMode(self, *args)

    def GetLayerMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetLayerMode(self, *args)

    def GetNameMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetNameMode(self, *args)

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        doc: TDocStd_Document
        filename: TCollection_AsciiString
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers a document and writes it to a iges file returns true if translation is ok.

        Parameters
        ----------
        doc: TDocStd_Document
        filename: char *
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_Perform(self, *args)

    def SetColorMode(self, *args) -> "void":
        r"""
        Set colormode for indicate write colors or not.

        Parameters
        ----------
        colormode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetColorMode(self, *args)

    def SetLayerMode(self, *args) -> "void":
        r"""
        Set layermode for indicate write layers or not.

        Parameters
        ----------
        layermode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetLayerMode(self, *args)

    def SetNameMode(self, *args) -> "void":
        r"""
        Set namemode for indicate write name or not.

        Parameters
        ----------
        namemode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetNameMode(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Transfers a document to a iges model returns true if translation is ok.

        Parameters
        ----------
        doc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers labels to a iges model returns true if translation is ok.

        Parameters
        ----------
        labels: TDF_LabelSequence
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers label to a iges model returns true if translation is ok.

        Parameters
        ----------
        label: TDF_Label
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_Transfer(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESCAFControl.delete_IGESCAFControl_Writer

# Register IGESCAFControl_Writer in _IGESCAFControl:
_IGESCAFControl.IGESCAFControl_Writer_swigregister(IGESCAFControl_Writer)





