from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

MMgt_TShared = NewType('MMgt_TShared', Standard_Transient)

# harray1 classes
# harray2 classes
# hsequence classes

